@@ -65,7 +65,7 @@ from .Core.AlertWatcher import AlertWatcher
 from .Core.MyCache import MyCache
 from .Core.roam import NetworkManagerHelper
 from .Core.UpdateList import UpdateList
-from .Core.utils import get_arch, get_dist
+from .Core.utils import get_arch, get_dist, SoftwarePropertiesPage
 from .backend import (InstallBackend,
                       get_backend)
 
@@ -198,9 +198,9 @@ class UpdateManager(Gtk.Window):
         self._start_pane(None)
         sys.exit(0)
 
-    def show_settings(self):
+    def show_settings(self, page_number=SoftwarePropertiesPage.updates):
         cmd = ["/usr/bin/software-properties-gtk",
-               "--open-tab", "2"]
+               "--open-tab", str(page_number)]
 
         if "WAYLAND_DISPLAY" not in os.environ:
             cmd += ["--toplevel", "%s" % self.get_window().get_xid()]
@@ -284,30 +284,27 @@ class UpdateManager(Gtk.Window):
                 time.sleep(0.05)
             s = json.load(p.stdout)
             for package in s.get('packages', []):
+                if package.get('service_name', '') == 'standard-security':
+                    continue
                 status = package.get('status', '')
-                if status == 'pending_attach':
+                if (
+                    status == 'pending_attach'
+                    or status == 'pending_enable'
+                    or status == 'upgrade_available'
+                ):
                     name = package.get('package', '')
                     version = package.get('version', '')
                     size = package.get('download_size', 0)
-                    self.ua_security_packages.append((name, version, size))
+                    downloadable = status == 'upgrade_available'
+                    self.ua_security_packages.append(
+                        (name, version, size, downloadable)
+                    )
+            self.cache.create_pro_cache(self.ua_security_packages)
 
     def _make_available_pane(self, install_count, need_reboot=False,
                              cancelled_update=False, error_occurred=False):
         self._check_hwe_support_status()
-        if install_count == 0:
-            # Need Restart > New Release > No Updates
-            if need_reboot:
-                return NeedRestartDialog(self)
-            dist_upgrade = self._check_meta_release()
-            if dist_upgrade:
-                return dist_upgrade
-            elif cancelled_update:
-                return StoppedUpdatesDialog(self)
-            elif self.hwe_replacement_packages:
-                return HWEUpgradeDialog(self)
-            else:
-                return NoUpdatesDialog(self, error_occurred=error_occurred)
-        else:
+        if install_count != 0 or len(self.ua_security_packages) > 0:
             header = None
             desc = None
             if error_occurred:
@@ -320,6 +317,19 @@ class UpdateManager(Gtk.Window):
             elif self.hwe_replacement_packages:
                 return HWEUpgradeDialog(self)
             return UpdatesAvailable(self, header, desc, need_reboot)
+        else:
+            # Need Restart > New Release > No Updates
+            if need_reboot:
+                return NeedRestartDialog(self)
+            dist_upgrade = self._check_meta_release()
+            if dist_upgrade:
+                return dist_upgrade
+            elif cancelled_update:
+                return StoppedUpdatesDialog(self)
+            elif self.hwe_replacement_packages:
+                return HWEUpgradeDialog(self)
+            else:
+                return NoUpdatesDialog(self, error_occurred=error_occurred)
 
     def start_error(self, update_and_retry, header, desc):
         if update_and_retry:
